@@ -7,17 +7,18 @@
 #include <QProcessEnvironment>
 #include <QStandardPaths>
 
-#include "themepreviewer.h"
 #include "config.h"
+#include "themepreviewer.h"
 
 const QString ThemePreviewer::gtk3PreviewerExecutablePath = QStandardPaths::findExecutable(QStringLiteral("gtk3_preview"), {CMAKE_INSTALL_FULL_LIBEXECDIR});
 
-ThemePreviewer::ThemePreviewer(QObject *parent) : QObject(parent),
-gtk3PreviewerProccess()
+ThemePreviewer::ThemePreviewer(QObject *parent)
+    : QObject(parent)
+    , gtk3PreviewerProccess()
 {
 }
 
-void ThemePreviewer::showGtk3App(const QString& themeName)
+void ThemePreviewer::showGtk3App(const QString &themeName)
 {
     if (gtk3PreviewerProccess.state() == QProcess::ProcessState::NotRunning) {
         QProcessEnvironment gtk3PreviewEnvironment = QProcessEnvironment::systemEnvironment();
